bitrix24

package module
v0.0.0-...-ad894ae Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2022 License: MIT Imports: 8 Imported by: 0

Documentation

Overview

The package provides a convenient interface for working with Bitrix24 CRM using webhooks.

Documentation for this package can be found in the doc folder in this repository.

The Bitrix24 user documentation in English can be found on this page: https:helpdesk.bitrix24.com/ The Bitrix24 developer documentation in English can be found on this page: https:helpdesk.bitrix24.com/documentation.php

(All terms in the comments are used in accordance with the terminology of Bitrix24)

All current features of the Bitrix24 CRM API are supported:

  • [CRM] Working with leads, deals, contacts, companies, products, invoices, details, and more;
  • [Bots] Creating interactive chatbots;
  • [Tasks] Task and project management;
  • [Calendar] Create calendars, meetings, and manage all calendar entities;
  • [Departaments] Working with departments;
  • [Users] Working with users;
  • [Time] Accounting of working hours;
  • [Mail] Mail Service Management;
  • [Notifications] Bitrix24 Notification Management;
  • [Blog] CRUD operations with the Bitrix24 blog;
  • [Business processes] Service for working with integrated automation (business processes);
  • [Messages] Managing chat messages;
  • [Chat] Bitrix24 Chat Management.
  • And others...

If you do not agree with some aspects of the package, please contact the author.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Connect

type Connect struct {
	Webhook string
}

Connection setting with Bitrix24

func (Connect) Request

func (b Connect) Request(function string, parameters Parameters) (result map[string]interface{}, err error)

The method allows accessing the Bitrix24 API endpoints and returns map[string]interface{}.

Example:

b24 := bitrix24.Connect{
    Webhook: "https://example.bitrix24.ru/rest/1/jwifhewuioqpkjhgje/",
}

response, err := b24.Request("crm.contact.list", bitrix24.Parameters{
    Value: map[string][]string{
    	"filter[ID]": {"1"},
    	"select[]":   {"ID", "NAME"},
    	"start":      {"-1"},
    },
})
if err != nil {
	panic(err)
}

fmt.Println(response)

You need to use the method only if the endpoint you want to call is not implemented in this package. If possible, it is necessary to use more specific methods defined in this package to work with Bitrix24 entities.

type Parameters

type Parameters struct {
	Value map[string][]string
	File  map[string][]*os.File
}

Jump to